@@ -48,7 +48,7 @@ FILE_FRAGMENT_SIZE_BYTES =  10 * 1024 * 1024 # 10 MiB, because it doesn't really
 
 
 def sha1_gnutella(filepath, fragment_size = FILE_FRAGMENT_SIZE_BYTES): 
-    """Calculate the sha1-hash and output it base32 encoded as is required by magnet links. 
+    """Calculate the sha1 hash and output it base32 encoded as is required by magnet links. 
     
     @param filepath: The path to the file to hash. Must be a file! This function is too low level to add recursion into subdirectories. 
     @type filepath: String
@@ -56,7 +56,7 @@ def sha1_gnutella(filepath, fragment_size = FILE_FRAGMENT_SIZE_BYTES):
     @param fragment_size: Length of the fragment to read in bytes.
     @type fragment_size: Int
     
-    @return: The sha1-hash, base32 encoded (String). 
+    @return: The sha1 hash, base32 encoded (String). 
     """
     
     # As really first part, we check, if the path leads to a file. If it doesn't we just return. 
@@ -127,6 +127,8 @@ filepath = "sha1_gnutella.py"
 def test_speed(files, min=1024 * 1024, max=15*1024*1024, step=1024 * 1024):
     """Test different settings of the fragment_size. 
     
+    Result: The fragment_size is almost irrelevant. Anything between 512kiB and 10MiB offers about the same speed.
+    
     @param files: The files to hash.
     @type files: List
     @return: None
